@@ -7,7 +7,7 @@ Photo uploader, main command line script.
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2007 - 2008 Michal Čihař
+Copyright © 2007 - 2009 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -32,8 +32,8 @@ import os
 CONFIGFILE = '~/.photo-upload'
 CONFIGDEFAULTS = {
         'photo-upload' : {
-            'service' : 'droxi.cz',
-            'open-browser' : 'No',
+            'service' : 'imageshack.us',
+            'open-browser' : False,
             'use-browser' : '',
             }
         }
